class UC:
    domain = "https://userscloud.com"

    def __init__(self, *, debug: bool = False):
        self.debug = debug


